/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#include <sys/types.h>
#include <stdbool.h>
#include <aul_comp_types.h>

#include "amd_compinfo.h"

typedef void *comp_status_h;

typedef enum {
	CT_FRAME_COMP,
	CT_SERVICE_COMP,
} comp_type_e;

const char *_comp_status_generate_instance(const char *comp_id);

int _comp_status_add_comp_info(compinfo_h ci, pid_t pid,
		const char *instance_id, bool is_subcomp);

comp_status_h _comp_status_find(const char *comp_id);

comp_status_h _comp_status_find_by_instance_id(const char *instance_id);

comp_status_h _comp_status_find_by_window(int window);

comp_status_h _comp_status_find_v2(pid_t pid, const char *instance_id);

pid_t _comp_status_get_pid(comp_status_h h);

const char *_comp_status_get_comp_id(comp_status_h h);

const char *_comp_status_get_instance_id(comp_status_h h);

int _comp_status_get_comp_type(comp_status_h h);

const char *_comp_status_get_leader_id(comp_status_h h);

int _comp_status_set_leader_id(comp_status_h h, const char *instance_id);

int _comp_status_get_status(comp_status_h h);

int _comp_status_set_window(comp_status_h h, int window);

int _comp_status_init(void);

void _comp_status_fini(void);
