/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef COMPONENT_INFO_H_
#define COMPONENT_INFO_H_

#include <unistd.h>
#include <aul_comp_info_internal.h>
#include <bundle_cpp.h>

#include <string>
#include <memory>
#include <vector>

namespace component_manager {

class ComponentInfo {
 public:
  class LocalizedInfo {
   public:
    LocalizedInfo(std::string locale, std::string icon, std::string label);
    virtual ~LocalizedInfo();

    std::string GetLocale();
    std::string GetIcon();
    std::string GetLabel();

   private:
    std::string locale_;
    std::string icon_;
    std::string label_;
  };

 public:
  ComponentInfo(uid_t uid, std::string component_id);
  ComponentInfo(aul_compinfo_h info, uid_t uid);
  virtual ~ComponentInfo();

  std::string GetAppID();
  std::string GetComponentID();
  std::string GetType();
  std::string GetLaunchMode();
  bool IsMainComponent();
  bool IsIconDisplay();
  bool IsManagedByTaskManager();
  std::vector<std::unique_ptr<LocalizedInfo>> GetLocalizedInfos();

  tizen_base::Bundle ToBundle();

 private:
  std::unique_ptr<std::remove_pointer<aul_compinfo_h>::type,
      decltype(aul_compinfo_destroy)*> handle_;
  uid_t uid_;
};

}  // namespace component_manager

#endif  // COMPONENT_INFO_H_
