/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef COMPONENT_MANAGER_H_
#define COMPONENT_MANAGER_H_

#include <amd.h>

#include <string>
#include <memory>

#include "dispatcher.h"

namespace component_manager {

class ComponentManager {
 private:
  ComponentManager() = default;
  ~ComponentManager() = default;

 public:
  ComponentManager(const ComponentManager&) = delete;
  ComponentManager& operator = (const ComponentManager&) = delete;

  static ComponentManager& GetInst() {
    static ComponentManager inst;
    if (!inst.initialized_)
      inst.Init();
    return inst;
  }

  int Register();
  int Dispatch(std::unique_ptr<Request> req);

 private:
  void Init();
  int RegisterCommands();
  int RegisterCynaraCheckers();

 private:
  static int OnDispatch(amd_request_h req);

 private:
  bool initialized_ = false;
  std::unique_ptr<Dispatcher> dispatcher_;
};

}  // namespace component_manager

#endif  // COMPONENT_MANAGER_H_
