/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef REQUEST_H_
#define REQUEST_H_

#include <amd.h>
#include <unistd.h>

#include <bundle_cpp.h>

namespace component_manager {

class Request {
 public:
  Request(amd_request_h req);
  Request(int fd, int cmd, uid_t target_uid, tizen_base::Bundle b);
  ~Request();

  Request(const Request& req);
  Request& operator = (const Request& req);
  Request(Request&& req) noexcept;
  Request& operator = (Request&& req) noexcept;

  int RemoveFd();
  int GetFd() const;
  int GetCmd() const;
  uid_t GetTargetUid() const;
  const tizen_base::Bundle& GetBundle() const;

 private:
  int fd_;
  int cmd_;
  uid_t target_uid_;
  tizen_base::Bundle b_;
};

}  // namespace component_manager

#endif  // REQUEST_H_
