/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <memory>

#include "request_handler.h"
#include "private.h"

namespace component_manager {

RequestHandler::RequestHandler(int cmd, std::string name)
  : cmd_(cmd), name_(std::move(name)) {
}

RequestHandler::~RequestHandler() = default;

RequestHandler::RequestHandler(const RequestHandler& handler) {
  cmd_ = handler.cmd_;
  name_ = handler.name_;
}

RequestHandler& RequestHandler::operator = (const RequestHandler& handler) {
  if (this != &handler) {
    cmd_ = handler.cmd_;
    name_ = handler.name_;
  }
  return *this;
}

RequestHandler::RequestHandler(RequestHandler&& handler) noexcept {
  cmd_ = handler.cmd_;
  handler.cmd_ = 0;
  name_ = std::move(handler.name_);
}

RequestHandler& RequestHandler::operator = (RequestHandler&& handler) noexcept {
  if (this != &handler) {
    cmd_ = handler.cmd_;
    handler.cmd_ = 0;
    name_ = std::move(handler.name_);
  }
  return *this;
}

int RequestHandler::Handle(std::unique_ptr<Request>& req) {
  _W("Command: %s[%d]", name_.c_str(), cmd_);
  return 0;
}

int RequestHandler::GetCmd() const {
  return cmd_;
}

std::string RequestHandler::GetName() {
  return name_;
}

}  // namespace component_manager
