/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#include <sys/types.h>
#include <unistd.h>
#include <bundle.h>

/**
 * @brief Intializes the RUA information.
 *
 * @return      @c 0 on success,
 *              otherwise a negative error value
 */
int _rua_info_init(void);

/**
 * @brief Finalizes the RUA information.
 */
void _rua_info_fini(void);

/**
 * @brief Adds a RUA information.
 *
 * @param[in]   kb              The bundle object
 * @param[in]   pid             The process ID
 *
 * @return      @c 0 on success,
 *              otherwise a negative error value
 */
int _rua_info_add(bundle *kb, pid_t pid);

/**
 * @brief Removes the RUA information.
 *
 * @param[in]   kb              The bundle object
 * @param[in]   uid             The user ID
 *
 * @return      @c 0 on success,
 *              otherwise a negative error value
 */
int _rua_info_remove(bundle *kb, uid_t uid);

/**
 * @brief Updates the image path of the RUA information.
 *
 * @param[in]   image           The image path
 *
 * @return      @c 0 on success,
 *              otherwise a negative error value
 */
int _rua_info_update_image(const char *image);

/**
 * @brief Gets the image path of the instance.
 *
 * @param[in]   instance_id     The ID of the instance
 *
 * @return      @c the image path on success,
 *              otherwise a nullptr
 */
const char *_rua_info_get_image(const char *instance_id);
