/*
 * Copyright (c) 2015 - 2019 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#include <stdint.h>
#include <stdbool.h>
#include <glib.h>

typedef struct app_group_s *app_group_h;

typedef GList *app_group_node_h;

typedef void (*app_group_foreach_context_cb)(const char *id, pid_t pid,
		int wid, bool fg, void *user_data);

app_group_h _app_group_find(const char *id);

const char *_app_group_get_leader_id_by_window(int window);

const char *_app_group_get_id(pid_t pid);

void _app_group_get_group_pids(app_group_h group, int *cnt, pid_t **pids);

void _app_group_get_leader_pids(int *cnt, pid_t **pids);

pid_t _app_group_get_leader_pid(app_group_h h);

void _app_group_get_idle_pids(int *cnt, pid_t **pids);

char **_app_group_get_leader_ids(int *cnt);

int _app_group_get_count(app_group_h group);

int _app_group_foreach_context(app_group_h group,
		app_group_foreach_context_cb callback,
		void *user_data);

int _app_group_get_idle_count(void);

int _app_group_foreach_idle_context(app_group_foreach_context_cb callback,
		void *user_data);

int _app_group_init(void);

void _app_group_fini(void);

app_group_node_h _app_group_node_find(const char *id);

int _app_group_node_get_window(app_group_node_h node);

void _app_group_node_lower(app_group_node_h node, bool *exit);

void _app_group_node_clear_top(app_group_node_h node, uid_t uid);

bool _app_group_node_get_fg_flag(app_group_node_h node);

int _app_group_node_set_window(app_group_node_h node, int wid);
